@@ -6,40 +6,27 @@
 //
 
 internal import ArgumentParser
+private import Darwin
 private import Foundation
 
-private var unknown: String { "unknown" }
-private var sysCtlByName: String { "sysctlbyname" }
-
 extension MAS {
 	/// Outputs mas config & related system info.
-	struct Config: AsyncParsableCommand {
+	struct Config: AsyncParsableCommand, Sendable {
 		static let configuration = CommandConfiguration(
 			abstract: "Output mas config & related system info"
 		)
 
-		@Flag(help: "Output as Markdown")
-		var markdown = false
-
-		/// Runs the command.
-		func run() async throws {
-			try await mas.run { await run(printer: $0) }
-		}
-
-		func run(printer: Printer) async {
-			if markdown {
-				printer.info("```text")
-			}
+		func run() async {
 			printer.info(
 				"""
-				mas ▁▁▁▁ \(Package.version)
+				mas ▁▁▁▁ \(MAS.version)
 				arch ▁▁▁ \(configStringValue("hw.machine"))
-				from ▁▁▁ \(Package.installMethod)
-				origin ▁ \(Package.gitOrigin)
-				rev ▁▁▁▁ \(Package.gitRevision)
-				driver ▁ \(Package.swiftDriverVersion)
-				swift ▁▁ \(Package.swiftVersion)
-				region ▁ \(await isoRegion?.alpha2 ?? unknown)
+				from ▁▁▁ \(MAS.installMethod)
+				origin ▁ \(MAS.gitOrigin)
+				rev ▁▁▁▁ \(MAS.gitRevision)
+				swift ▁▁ \(MAS.swiftVersion)
+				driver ▁ \(MAS.swiftDriverVersion)
+				region ▁ \(await region)
 				macos ▁▁ \(
 					ProcessInfo.processInfo.operatingSystemVersionString.dropFirst(8).replacingOccurrences(of: "Build ", with: "")
 				)
@@ -47,9 +34,6 @@ extension MAS {
 				cpu ▁▁▁▁ \(configStringValue("machdep.cpu.brand_string"))
 				"""
 			)
-			if markdown {
-				printer.info("```")
-			}
 		}
 	}
 }
@@ -69,3 +53,6 @@ private func configStringValue(_ name: String) -> String {
 
 	return String(cString: buffer, encoding: .utf8) ?? unknown
 }
+
+private let unknown = "unknown"
+private let sysCtlByName = "sysctlbyname"
