@@ -6,12 +6,14 @@
 //
 
 internal import ArgumentParser
+private import Foundation
 
 extension MAS {
 	/// Gets & installs free apps from the App Store.
 	struct Get: AsyncParsableCommand, Sendable {
 		static let configuration = CommandConfiguration(
 			abstract: "Get & install free apps from the App Store",
+			discussion: requiresRootPrivilegesMessage,
 			aliases: ["purchase"]
 		)
 
@@ -20,6 +22,7 @@ extension MAS {
 
 		func run() async {
 			do {
+				try requireRootUserAndWheelGroup(withErrorMessageSuffix: "to get apps")
 				await run(installedApps: try await installedApps, appCatalog: ITunesSearchAppCatalog())
 			} catch {
 				printer.error(error: error)
