@@ -9,14 +9,14 @@ internal import ArgumentParser
 private import Foundation
 
 extension MAS {
-	/// Opens Mac App Store app pages in the default web browser.
+	/// Opens App Store app pages in the default web browser.
 	///
 	/// Uses the iTunes Lookup API:
 	///
 	/// https://performance-partners.apple.com/search-api
 	struct Home: AsyncParsableCommand, Sendable {
 		static let configuration = CommandConfiguration(
-			abstract: "Open Mac App Store app pages in the default web browser"
+			abstract: "Open App Store app pages in the default web browser"
 		)
 
 		@OptionGroup
@@ -26,15 +26,15 @@ extension MAS {
 			await run(appCatalog: ITunesSearchAppCatalog())
 		}
 
-		func run(appCatalog: some AppCatalog) async {
+		private func run(appCatalog: some AppCatalog) async {
 			await run(catalogApps: await requiredAppIDsOptionGroup.appIDs.lookupCatalogApps(from: appCatalog))
 		}
 
-		func run(catalogApps: [CatalogApp]) async {
+		func run(catalogApps: [CatalogApp]) async { // swiftformat:disable:this organizeDeclarations
 			await run(appStorePageURLs: catalogApps.map(\.appStorePageURL))
 		}
 
-		func run(appStorePageURLs: [String]) async {
+		private func run(appStorePageURLs: [String]) async { // swiftformat:disable:this organizeDeclarations
 			await appStorePageURLs.forEach(attemptTo: "open") { appStorePageURL in
 				guard let url = URL(string: appStorePageURL) else {
 					throw MASError.urlParsing(appStorePageURL)
