@@ -6,12 +6,14 @@
 //
 
 internal import ArgumentParser
+private import Foundation
 
 extension MAS {
 	/// Installs previously gotten apps from the App Store.
 	struct Install: AsyncParsableCommand, Sendable {
 		static let configuration = CommandConfiguration(
-			abstract: "Install previously gotten apps from the App Store"
+			abstract: "Install previously gotten apps from the App Store",
+			discussion: requiresRootPrivilegesMessage
 		)
 
 		@OptionGroup
@@ -21,6 +23,7 @@ extension MAS {
 
 		func run() async {
 			do {
+				try requireRootUserAndWheelGroup(withErrorMessageSuffix: "to install apps")
 				await run(installedApps: try await installedApps, appCatalog: ITunesSearchAppCatalog())
 			} catch {
 				printer.error(error: error)
