@@ -7,6 +7,7 @@
 
 internal import ArgumentParser
 private import Foundation
+private import ObjectiveC
 
 extension MAS {
 	/// Outputs app information from the App Store.
@@ -41,7 +42,7 @@ extension MAS {
 					"""
 					\(catalogApp.name) \(catalogApp.version) [\(catalogApp.formattedPrice)]
 					By: \(catalogApp.sellerName)
-					Released: \(catalogApp.releaseDate.humanReadableDate)
+					Released: \(catalogApp.releaseDate.isoCalendarDate)
 					Minimum OS: \(catalogApp.minimumOSVersion)
 					Size: \(catalogApp.fileSizeBytes.humanReadableSize)
 					From: \(catalogApp.appStorePageURL)
@@ -54,14 +55,20 @@ extension MAS {
 }
 
 private extension String {
-	var humanReadableSize: String {
-		ByteCountFormatter.string(fromByteCount: Int64(self) ?? 0, countStyle: .file)
+	var humanReadableSize: Self {
+		Int64(self).map { size in
+			let formatter = ByteCountFormatter()
+			formatter.allowedUnits = .useMB
+			formatter.allowsNonnumericFormatting = false
+			return formatter.string(fromByteCount: size)
+		}
+		?? self // swiftformat:disable:this indent
 	}
 
-	var humanReadableDate: String {
+	var isoCalendarDate: Self {
 		ISO8601DateFormatter().date(from: self).map { date in
 			ISO8601DateFormatter.string(from: date, timeZone: .current, formatOptions: [.withFullDate])
 		}
-		?? "" // swiftformat:disable:this indent
+		?? self // swiftformat:disable:this indent
 	}
 }
