@@ -15,7 +15,8 @@ extension MAS {
 	/// Uninstalls apps installed from the App Store.
 	struct Uninstall: AsyncParsableCommand, Sendable {
 		static let configuration = CommandConfiguration(
-			abstract: "Uninstall apps installed from the App Store"
+			abstract: "Uninstall apps installed from the App Store",
+			discussion: requiresRootPrivilegesMessage
 		)
 
 		/// Flag indicating that removal shouldn't be performed.
@@ -26,6 +27,7 @@ extension MAS {
 
 		func run() async {
 			do {
+				try requireRootUserAndWheelGroup(withErrorMessageSuffix: "to uninstall apps")
 				try run(installedApps: try await installedApps)
 			} catch {
 				printer.error(error: error)
@@ -33,10 +35,6 @@ extension MAS {
 		}
 
 		private func run(installedApps: [InstalledApp]) throws {
-			guard NSUserName() == "root" else {
-				throw MASError.runtimeError("Apps installed from the App Store require root permission to uninstall")
-			}
-
 			let uninstallingAppPathOrderedSet = uninstallingAppPathOrderedSet(from: installedApps)
 			guard !uninstallingAppPathOrderedSet.isEmpty else {
 				return
@@ -66,18 +64,14 @@ extension MAS {
 	}
 }
 
-/// Uninstalls all apps located at any of the elements of `appPaths`.
+/// Uninstalls all apps located at any of the elements of `appPathSequence`.
 ///
-/// - Parameter: appPaths: Paths to apps to be uninstalled.
+/// - Parameter: appPathSequence: Paths to apps to be uninstalled.
 /// - Throws: An `Error` if any problem occurs.
 private func uninstallApps(atPaths appPathSequence: some Sequence<String>) throws {
 	let processInfo = ProcessInfo.processInfo
-	guard let uid = processInfo.sudoUID else {
-		throw MASError.runtimeError("Failed to get sudo uid")
-	}
-	guard let gid = processInfo.sudoGID else {
-		throw MASError.runtimeError("Failed to get sudo gid")
-	}
+	let uid = try processInfo.sudoUID
+	let gid = try processInfo.sudoGID
 	guard let finder = SBApplication(bundleIdentifier: "com.apple.finder") as (any FinderApplication)? else {
 		throw MASError.runtimeError("Failed to obtain Finder access: bundle com.apple.finder does not exist")
 	}
@@ -96,30 +90,50 @@ private func uninstallApps(atPaths appPathSequence: some Sequence<String>) throw
 			MAS.printer.error("Failed to get gid of", appPath)
 			continue
 		}
-		guard chown(appPath, uid, gid) == 0 else {
-			MAS.printer.error("Failed to change ownership of", appPath.quoted, "to uid", uid, "& gid", gid)
+
+		do {
+			try run(asEffectiveUID: 0, andEffectiveGID: 0) {
+				try fileManager.setAttributes([.ownerAccountID: uid, .groupOwnerAccountID: gid], ofItemAtPath: appPath)
+			}
+		} catch {
+			MAS.printer.error("Failed to change ownership of", appPath.quoted, "to uid", uid, "& gid", gid, error: error)
 			continue
 		}
 
 		var chownPath = appPath
 		defer {
-			if chown(chownPath, appUID, appGID) != 0 {
-				MAS.printer.warning("Failed to revert ownership of", chownPath.quoted, "back to uid", appUID, "& gid", appGID)
+			do {
+				try run(asEffectiveUID: 0, andEffectiveGID: 0) {
+					try fileManager.setAttributes(
+						[.ownerAccountID: appUID, .groupOwnerAccountID: appGID],
+						ofItemAtPath: chownPath
+					)
+				}
+			} catch {
+				MAS.printer.warning(
+					"Failed to revert ownership of",
+					chownPath.quoted,
+					"back to uid",
+					appUID,
+					"& gid",
+					appGID,
+					error: error
+				)
 			}
 		}
 
-		let object = items().object(atLocation: URL(fileURLWithPath: appPath))
+		let object = items().object(atLocation: URL(fileURLWithPath: appPath, isDirectory: true))
 		guard let item = object as? any FinderItem else {
 			MAS.printer.error(
 				"""
-				Failed to obtain Finder access: FinderApplication.items().object(atLocation: URL(fileURLWithPath:\
-				 \"\(appPath)\") is a \(type(of: object)) that does not conform to FinderItem
+				Failed to obtain Finder access for \(appPath.quoted): FinderApplication.items().object(atLocation:) returned a\
+				 \(type(of: object)), which does not conform to FinderItem
 				"""
 			)
 			continue
 		}
 		guard let delete = item.delete else {
-			MAS.printer.error("Failed to obtain Finder access: FinderItem.delete does not exist")
+			MAS.printer.error("Failed to obtain Finder access for \(appPath.quoted): FinderItem.delete does not exist")
 			continue
 		}
 		guard let deletedURLString = (delete() as any FinderItem).URL else {
