@@ -10,9 +10,13 @@ internal import Foundation
 enum MASError: Error {
 	case noCatalogAppsFound(for: String)
 	case notSupported
-	case runtimeError(String)
+	case runtimeError(String, error: (any Error)? = nil)
 	case unknownAppID(AppID)
 	case urlParsing(String)
+
+	static func runtimeError(_ message: String, error: String) -> Self {
+		runtimeError(message, error: runtimeError(error))
+	}
 }
 
 extension MASError: CustomStringConvertible {
@@ -25,8 +29,8 @@ extension MASError: CustomStringConvertible {
 			This command is not supported on this macOS version due to changes in macOS
 			See https://github.com/mas-cli/mas#known-issues
 			"""
-		case let .runtimeError(message):
-			message
+		case let .runtimeError(message, error):
+			"\(message)\(error.map { ":\n\($0)" } ?? "")"
 		case let .unknownAppID(appID):
 			"No apps found in the App Store for \(appID)"
 		case let .urlParsing(string):
