@@ -12,3 +12,9 @@ extension String {
 		"'\(replacingOccurrences(of: "'", with: "\\'"))'"
 	}
 }
+
+extension String? {
+	var quoted: String {
+		map(\.quoted) ?? "unknown"
+	}
+}
